@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     AnalysisTypeType,
@@ -101,7 +101,7 @@ _OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
     "_OptionalAssociateRepositoryRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "KMSKeyDetails": "KMSKeyDetailsTypeDef",
     },
     total=False,
@@ -208,7 +208,7 @@ _RequiredCodeReviewTypeTypeDef = TypedDict(
 _OptionalCodeReviewTypeTypeDef = TypedDict(
     "_OptionalCodeReviewTypeTypeDef",
     {
-        "AnalysisTypes": List[AnalysisTypeType],
+        "AnalysisTypes": Sequence[AnalysisTypeType],
     },
     total=False,
 )
@@ -364,9 +364,9 @@ _RequiredListCodeReviewsRequestRequestTypeDef = TypedDict(
 _OptionalListCodeReviewsRequestRequestTypeDef = TypedDict(
     "_OptionalListCodeReviewsRequestRequestTypeDef",
     {
-        "ProviderTypes": List[ProviderTypeType],
-        "States": List[JobStateType],
-        "RepositoryNames": List[str],
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[JobStateType],
+        "RepositoryNames": Sequence[str],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -400,8 +400,8 @@ _OptionalListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "UserIds": List[str],
-        "RecommendationIds": List[str],
+        "UserIds": Sequence[str],
+        "RecommendationIds": Sequence[str],
     },
     total=False,
 )
@@ -458,10 +458,10 @@ ListRecommendationsResponseTypeDef = TypedDict(
 ListRepositoryAssociationsRequestRequestTypeDef = TypedDict(
     "ListRepositoryAssociationsRequestRequestTypeDef",
     {
-        "ProviderTypes": List[ProviderTypeType],
-        "States": List[RepositoryAssociationStateType],
-        "Names": List[str],
-        "Owners": List[str],
+        "ProviderTypes": Sequence[ProviderTypeType],
+        "States": Sequence[RepositoryAssociationStateType],
+        "Names": Sequence[str],
+        "Owners": Sequence[str],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -525,7 +525,7 @@ PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
-        "Reactions": List[ReactionType],
+        "Reactions": Sequence[ReactionType],
     },
 )
 
@@ -716,7 +716,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -733,7 +733,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
